AttriaxAndroid class

Android implementation of AttriaxPlatform.

Inheritance
  • Object
  • PlatformInterface
  • AttriaxAndroid

Constructors

AttriaxAndroid()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

collectInstallReferrer() Future<AttriaxInstallReferrerContext>
inherited
collectNativeContext({bool collectAdvertisingId = true}) Future<AttriaxNativeContext>
inherited
collectWebViewUserAgent() Future<String?>
inherited
consumePendingCrashReport() Future<AttriaxPendingCrashReport?>
inherited
getTrackingAuthorizationStatus() Future<AttriaxTrackingAuthorizationStatus>
inherited
missingPluginInstallReferrerContext(MissingPluginException error) → AttriaxInstallReferrerContext
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openBrowserUrl({required Uri uri, required AttriaxResolvedUrlOpenMode openMode}) Future<bool>
inherited
platformExceptionInstallReferrerContext(PlatformException error) → AttriaxInstallReferrerContext
readAttributionClipboard() Future<String?>
inherited
requestTrackingAuthorization({Duration? timeout}) Future<AttriaxTrackingAuthorizationStatus>
inherited
setAutomaticCrashReportingEnabled({required bool enabled}) Future<void>
inherited
toString() String
A string representation of this object.
inherited
updateSkanConversionValue({required int fineValue, AttriaxSkanCoarseValue? coarseValue, bool lockWindow = false}) Future<AttriaxSkanUpdateResult>
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerWith() → void